@@ -1,9 +1,12 @@
 import abc
 import collections
 import datetime
+import hashlib
+import itertools
 import lxml.etree
 import mimetypes
 import posixpath
+import re
 import uuid
 import zipfile
 
@@ -78,8 +81,23 @@ class Epub(abc.ABC):
 			return
 
 		with self._zf.open(zi) as f:
-			enctree = lxml.etree.parse(f).getroot()
-		self._read_encryption(enctree)
+			tree = lxml.etree.parse(f).getroot()
+
+		xml_ns = {'enc': 'http://www.w3.org/2001/04/xmlenc#'}
+		idpf_key = IdpfKey(str(self.uid))
+
+		for tag in tree.findall('./enc:EncryptedData', xml_ns):
+			meth = tag.find('./enc:EncryptionMethod', xml_ns)
+			if meth is None:
+				raise ValueError(f'Unsupported EncryptedData: missing algorithm')
+			alg = getxmlattr(meth, 'Algorithm')
+			if alg != 'http://www.idpf.org/2008/embedding':
+				raise ValueError(f'Unsupported encryption algorithm: {alg}')
+
+			ref = tag.find('./enc:CipherData/enc:CipherReference', xml_ns)
+			href = getxmlattr(ref, 'URI')
+
+			self._encryption[href] = idpf_key
 
 	def _init_write(self):
 		self.uid = AttributedString(str(uuid.uuid4()))
@@ -116,10 +134,6 @@ class Epub(abc.ABC):
 		pkg = self._xml_opf()
 		self._writestr(self._opfpath, lxml.etree.tostring(pkg, pretty_print=True))
 
-	@abc.abstractmethod
-	def _read_encryption(self, enctree): # pragma: no cover
-		...
-
 	@abc.abstractmethod
 	def _read_toc(self, opftree): # pragma: no cover
 		...
@@ -394,3 +408,18 @@ class Layout(dict):
 		if not isinstance(val, self.Item):
 			raise TypeError('The layout items needs to be Layout.Item elements')
 		super().__setitem__(key, val)
+
+
+class IdpfKey:
+	head = 1040
+
+	def __init__(self, uid):
+		print(repr(uid))
+		uid = re.sub('[\u0020\u0009\u000d\u000a]', '', uid)
+		self.key = hashlib.sha1(uid.encode('utf-8')).digest()
+
+	def __call__(self, data):
+		key = itertools.cycle(iter(self.key))
+		head, rest = data[:self.head], data[self.head:]
+		head = bytes([b ^ k for b, k in zip(head, key)])
+		return head + rest
