@@ -18,9 +18,6 @@ class Epub20(Epub):
 	version = '2.0'
 	_default_toc_path = 'toc.ncx'
 
-	def _read_encryption(self, tree): # pragma: no cover
-		raise NotImplementedError()
-
 	def _read_toc(self, opftree):
 		toc_id = getxmlattr(opftree.find('./opf:spine', NS), 'toc')
 		if toc_id is None:
