@@ -1,7 +1,4 @@
-import hashlib
-import itertools
 import lxml.etree
-import posixpath
 import re
 import uuid
 
@@ -29,23 +26,6 @@ class Epub30(Epub):
 			if val == 'cover-image':
 				self.cover = self.manifest[iid]
 
-	def _read_encryption(self, tree):
-		xml_ns = {'enc': 'http://www.w3.org/2001/04/xmlenc#'}
-		idpf_key = IdpfKey(str(self.uid))
-
-		for tag in tree.findall('./enc:EncryptedData', xml_ns):
-			meth = tag.find('./enc:EncryptionMethod', xml_ns)
-			if meth is None:
-				raise ValueError(f'Unsupported EncryptedData: missing algorithm')
-			alg = getxmlattr(meth, 'Algorithm')
-			if alg != 'http://www.idpf.org/2008/embedding':
-				raise ValueError(f'Unsupported encryption algorithm: {alg}')
-
-			ref = tag.find('./enc:CipherData/enc:CipherReference', xml_ns)
-			href = getxmlattr(ref, 'URI')
-
-			self._encryption[href] = idpf_key
-
 	def _read_spine(self, opftree):
 		super()._read_spine(opftree)
 		for item in opftree.findall('./opf:spine/opf:itemref', NS):
@@ -313,18 +293,3 @@ class Epub30(Epub):
 		data = lxml.etree.tostring(data, pretty_print=True, method='html')
 
 		self.writestr(self.toc.item, data)
-
-
-class IdpfKey:
-	head = 1040
-
-	def __init__(self, uid):
-		print(repr(uid))
-		uid = re.sub('[\u0020\u0009\u000d\u000a]', '', uid)
-		self.key = hashlib.sha1(uid.encode('utf-8')).digest()
-
-	def __call__(self, data):
-		key = itertools.cycle(iter(self.key))
-		head, rest = data[:self.head], data[self.head:]
-		head = bytes([b ^ k for b, k in zip(head, key)])
-		return head + rest
